//---------------------------------------------------------------------------
#include <vcl\vcl.h>
#pragma hdrstop

#include "ModInstForm.h"
//---------------------------------------------------------------------------
#pragma resource "*.dfm"
TModInstFrm *ModInstFrm;
//---------------------------------------------------------------------------
__fastcall TModInstFrm::TModInstFrm(TComponent* Owner)
	: TForm(Owner)
{
}
//---------------------------------------------------------------------------
void __fastcall TModInstFrm::FormCreate(TObject *Sender)
{
	AboutText = new TRxRichEditX(this);
	AboutText->Parent = Panel2;
	AboutText->Align = alClient;
	AboutText->ScrollBars = ssVertical;
	AboutText->ReadOnly = true;	
}
//---------------------------------------------------------------------------
